Authors
=======

- Alec Deason <alecwd@uw.edu>
- James Collins <collijk@uw.edu>
- Michelle Park <hpark3@uw.edu>
- Abraham Flaxman <abie@uw.edu>
- Everett Mumford <emumford@uw.edu>
- Zane Rankin <zrankin@uw.edu>
- Paola Pedroza <ppedroza@uw.edu>
- Erika Eldrenkamp <eeldren@uw.edu>
- Cody Horst <chorst@uw.edu>
- Kate Wilson <kwilson7@uw.edu>

Current Maintainers
-------------------

- James Collins <collijk@uw.edu>
- Michelle Park <hpark3@uw.edu>
- Cody Horst <chorst@uw.edu>
- Kate Wilson <kwilson7@uw.edu>
- Abraham Flaxman <abie@uw.edu>
